@@ -1,7 +1,7 @@
 use proc_macro::Span;
 use proc_macro2::TokenStream;
 use pyo3::type_object::PyTypeObject;
-use pyo3::{AsPyRef, PyAny, PyErr, PyResult, Python, ToPyObject};
+use pyo3::{PyAny, PyErr, PyResult, Python, ToPyObject};
 use quote::{quote, quote_spanned};
 
 /// Format a nice error message for a python compilation error.
@@ -9,11 +9,11 @@ pub fn compile_error_msg(py: Python, error: PyErr, tokens: TokenStream) -> Token
 	let value = error.to_object(py);
 
 	if value.is_none(py) {
-		let error = format!("python: {}", error.ptype.as_ref(py).name());
+		let error = format!("python: {}", error.ptype(py).name().unwrap());
 		return quote!(compile_error! {#error});
 	}
 
-	if error.matches(py, pyo3::exceptions::SyntaxError::type_object(py)) {
+	if error.matches(py, pyo3::exceptions::PySyntaxError::type_object(py)) {
 		let line: Option<usize> = value.getattr(py, "lineno").ok().and_then(|x| x.extract(py).ok());
 		let msg: Option<String> = value.getattr(py, "msg").ok().and_then(|x| x.extract(py).ok());
 		if let (Some(line), Some(msg)) = (line, msg) {
@@ -24,8 +24,8 @@ pub fn compile_error_msg(py: Python, error: PyErr, tokens: TokenStream) -> Token
 		}
 	}
 
-	if let Some(tb) = &error.ptraceback {
-		if let Ok((file, line)) = get_traceback_info(tb.as_ref(py)) {
+	if let Some(tb) = &error.ptraceback(py) {
+		if let Ok((file, line)) = get_traceback_info(tb) {
 			if file == Span::call_site().source_file().path().to_string_lossy() {
 				if let Ok(msg) = value.as_ref(py).str() {
 					if let Some(span) = span_for_line(tokens, line) {
@@ -60,7 +60,7 @@ fn span_for_line(input: TokenStream, line: usize) -> Option<Span> {
 	let mut result = spans.next()?;
 	for span in spans {
 		result = match result.join(span) {
-			None => return Some(Span::from(result)),
+			None => return Some(result),
 			Some(span) => span,
 		}
 	}
